.. _bb_api:

Blackboard API Reference
========================

Blackboard REST API
-------------------

REST API call parameters must be specified in keyword form.

.. automodule:: blackboard_sync.blackboard.api
    :members:
    :undoc-members:

Blackboard Data Classes
-----------------------

.. automodule:: blackboard_sync.blackboard.blackboard
    :members:
    :undoc-members:
